@@ -1,7 +1,9 @@
 from typing import Optional
-from .base import EmailBackend
+
 from pythonit_toolkit.emails.templates import EmailTemplate
 
+from .base import EmailBackend
+
 
 class LocalEmailBackend(EmailBackend):
     def send_email(
@@ -11,12 +13,12 @@ class LocalEmailBackend(EmailBackend):
         subject: str,
         from_: str,
         to: str,
-        variables: Optional[dict[str, str]] = None
+        variables: Optional[dict[str, str]] = None,
     ):
-        print(f"=== Email sending ===")
+        print("=== Email sending ===")
         print(f"Template: {template}")
         print(f"From: {from_}")
         print(f"To: {to}")
         print(f"Subject: {subject}")
         print(f"Variables: {str(variables)}")
-        print(f"=== End Email sending ===")
+        print("=== End Email sending ===")
